=========
Changelog
=========

Here's the recent changes to Better Timeit.

.. changelog::
    :version: 1.1.1
    :released: 2014-05-02

    .. change::
        :tags: general

    Add a target-time option to the distutils command, to tune the target time
    for each run.

.. changelog::
    :version: 1.1
    :released: 2014-04-29

    .. change::
        :tags: general

        Add a distutils command to run timings from setup.py. Also add a
        setup() flag ``timeit_suite`` to set timeit module in setup.py.

.. changelog::
    :version: 1.0.1
    :released: 2014-04-29

    .. change::
        :tags: general

        A version that actually works: the 1.0 release didn't extract the body
        of the timeit function.

.. changelog::
    :version: 1.0
    :released: 2014-04-28

    .. change::
        :tags: general

        First version.
